<p align="center">
<a href="http://gdbgui.com"><img src="https://github.com/cs01/gdbgui/raw/master/images/gdbgui_banner.png"></a>
</p>

<h2 align="center">
A modern, browser-based frontend to gdb (gnu debugger)
</h2>

<p align="center">
<a href="https://github.com/cs01/gdbgui/raw/master/screenshots/gdbgui_animation.gif">
<img src="https://github.com/cs01/gdbgui/raw/master/screenshots/gdbgui_animation.gif">
</a>

</p>

<p align="center">
<a href="https://travis-ci.org/cs01/gdbgui"><img src="https://travis-ci.org/cs01/gdbgui.svg?branch=master" alt="image" /></a> <a href="https://pypi.python.org/pypi/gdbgui/"><img src="https://img.shields.io/badge/pypi-0.13.0.0-blue.svg" alt="image" /></a> <img src="https://img.shields.io/badge/python-2,3,pypy-blue.svg" alt="image" /> <a href="https://github.com/ambv/black"><img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Code style: black" /></a> <a href="https://github.com/prettier/prettier"><img src="https://img.shields.io/badge/code_style-prettier-ff69b4.svg?style=flat-square" alt="code style: prettier" /></a></p>



Add breakpoints, view stack traces, and more in C, C++, Go, and Rust! Perfect for beginners and experts. Simply run `gdbgui` from the terminal and a new tab will open in your browser.



## [Homepage](https://gdbgui.com)

Visit [gdbgui.com](https://gdbgui.com) to download, view documentation, installation instructions, screenshots and more.

## License

[GNU GPLv3]()

For alternate licensing schemes, contact <grassfedcode@gmail.com> for more information.

[gdbgui.com](https://gdbgui.com), [https://github.com/cs01/gdbgui](https://github.com/cs01/gdbgui), and [PyPI](https://pypi.python.org/pypi/gdbgui/) are the only official sources of gdbgui.

## Support gdbgui

You can support the project by [donating](https://www.paypal.me/grassfedcode/20), spreading the word, and reporting issues.
## Contributing

To add a feature or fix a bug, see [CONTRIBUTING](https://github.com/cs01/gdbgui/blob/master/CONTRIBUTING.md).

## Authors

`gdbgui` is primarily authored by Chad Smith, with [help from the community](https://github.com/cs01/gdbgui/graphs/contributors). Large contributions were made by @bobthekingofegypt, who added initial autocomplete functionality for the gdb terminal.

## Contact

<grassfedcode@gmail.com>
